# -*- coding: utf-8 -*-
# @Time : 2022/9/9 14:33
# @Author : Wang Hai
# @Email : nicewanghai@163.com
# @Code Specification : PEP8
# @File : Talk.py
# @Project : HaiHai

class Talk:

    @staticmethod
    def talk():
        while True:
            others_words = input()
            print("好的，知道了{}".format(others_words))




# -*- coding: utf-8 -*-
# @Time : 2022/9/9 14:36
# @Author : Wang Hai
# @Email : nicewanghai@163.com
# @Code Specification : PEP8
# @File : HowToAnswer.py
# @Project : HaiHai


class HowToAnswer(object):
    def __init__(self):
        pass

    def listen(self, word):
        pass

    def answer(self, words):
        pass




# -*- coding: utf-8 -*-
# @Time : 2022/10/19 13:06
# @Author : Wang Hai
# @Email : nicewanghai@163.com
# @Code Specification : PEP8
# @File : setup.py.py
# @Project : HaiHai
import setuptools

# 读取 README.md 得到详细介绍
# with open("readme.md", "r") as fh:
#     long_description = fh.read()

setuptools.setup(
    name="HaiChatbot",  # 名称
    version="0.0.4",  # 版本
    author="Wang Hai",  # 作者
    author_email="nicewanghai@163.com",  # 邮箱
    description="chatbot",  # 简介
    long_description="None",  # 详细介绍
    long_description_content_type="text/markdown",  # 详细介绍的文件类型
    url="https://github.com/Happleasei/HaiHai",  # 包的链接
    packages=setuptools.find_packages(),
    classifiers=["Programming Language :: Python :: 3", "License :: OSI Approved :: MIT License", "Operating System :: OS Independent"],
)

